[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#683746: rspamd packaging



On Thu, 2012-08-09 at 17:56 +0400, Vsevolod Stakhov wrote:
> Fixed them, thank you!
 Getting close. Found some spelling fixes, patch attached.

> I've uploaded the package: http://mentors.debian.net/package/rspamd
 Seems to be good. Please add the also attached watch file.

Regards,
Laszlo/GCS
diff -Nur orig.rspamd-0.5.1/src/dkim.c rspamd-0.5.1/src/dkim.c
--- orig.rspamd-0.5.1/src/dkim.c	2012-08-09 13:40:26.000000000 +0200
+++ rspamd-0.5.1/src/dkim.c	2012-08-09 23:15:05.168196938 +0200
@@ -475,7 +475,7 @@
 				}
 				break;
 			default:
-				g_set_error (err, DKIM_ERROR, DKIM_SIGERROR_UNKNOWN, "invalid dkim param lenght: %zd", taglen);
+				g_set_error (err, DKIM_ERROR, DKIM_SIGERROR_UNKNOWN, "invalid dkim param length: %zd", taglen);
 				state = DKIM_STATE_ERROR;
 				break;
 			}
diff -Nur orig.rspamd-0.5.1/src/lua/lua_redis.c rspamd-0.5.1/src/lua/lua_redis.c
--- orig.rspamd-0.5.1/src/lua/lua_redis.c	2012-08-09 13:40:26.000000000 +0200
+++ rspamd-0.5.1/src/lua/lua_redis.c	2012-08-09 23:16:44.964202086 +0200
@@ -343,7 +343,7 @@
 			}
 		}
 		else {
-			msg_info ("function requred as 4-th argument");
+			msg_info ("function required as 4-th argument");
 			lua_pushboolean (L, FALSE);
 		}
 	}
diff -Nur orig.rspamd-0.5.1/src/plugins/lua/ip_score.lua rspamd-0.5.1/src/plugins/lua/ip_score.lua
--- orig.rspamd-0.5.1/src/plugins/lua/ip_score.lua	2012-08-09 13:40:26.000000000 +0200
+++ rspamd-0.5.1/src/plugins/lua/ip_score.lua	2012-08-09 23:17:15.308203651 +0200
@@ -171,5 +171,5 @@
 		rspamd_config:register_post_filter(ip_score_set)
 	end
 else
-	rspamd_logger.err('cannot register module ip_score as it requres at least 9 version of lua API and rspamd >= 0.4.6')
+	rspamd_logger.err('cannot register module ip_score as it requires at least 9 version of lua API and rspamd >= 0.4.6')
 end
version=3
https://bitbucket.org/vstakhov/rspamd/downloads  .+rspamd-(\d+[\d\.]*).tar.gz

Reply to:
diff -Nur orig.rspamd-0.5.1/src/main.c rspamd-0.5.1/src/main.c
--- orig.rspamd-0.5.1/src/main.c	2012-08-09 13:40:26.000000000 +0200
+++ rspamd-0.5.1/src/main.c	2012-08-09 23:15:51.076199305 +0200
@@ -1074,14 +1074,14 @@
 #endif
 		if (do_terminate) {
 			do_terminate = 0;
-			msg_info ("catch termination signal, waiting for childs");
+			msg_info ("catch termination signal, waiting for children");
 			pass_signal_worker (rspamd_main->workers, SIGTERM);
 			break;
 		}
 		if (child_dead) {
 			child_dead = 0;
 			msg_debug ("catch SIGCHLD signal, finding terminated worker");
 			/* Remove dead child form childs list */
 			wrk = waitpid (0, &res, 0);
 			if ((cur = g_hash_table_lookup (rspamd_main->workers, GSIZE_TO_POINTER (wrk))) != NULL) {
 				/* Unlink dead process from queue and hash table */
@@ -1074,14 +1074,14 @@
 			child_dead = 0;
 			msg_debug ("catch SIGCHLD signal, finding terminated worker");
-			/* Remove dead child form childs list */
+			/* Remove dead child form children list */
 			wrk = waitpid (0, &res, 0);
 			if ((cur = g_hash_table_lookup (rspamd_main->workers, GSIZE_TO_POINTER (wrk))) != NULL) {